package com.test.jms;

import java.io.Serializable;
import java.util.List;
import javax.enterprise.context.ApplicationScoped;
import javax.jms.Connection;
import javax.jms.JMSException;
import javax.jms.MessageProducer;
import javax.jms.ObjectMessage;
import javax.jms.Queue;
import javax.jms.QueueConnectionFactory;
import javax.jms.Session;
import javax.naming.InitialContext;
import javax.naming.NamingException;
import javax.transaction.Transactional;

import org.slf4j.Logger;
import org.slf4j.LoggerFactory;

@ApplicationScoped
@Transactional
public class JmsClient {

	private static final Logger LOGGER = LoggerFactory.getLogger(JMSOperations.class);
	InitialContext ctx = null;
	Queue queue = null;
	QueueConnectionFactory factory = null;
	Connection connection = null;
	Session session = null;
	MessageProducer sender = null;
	ObjectMessage objectMessage = null;

	public void sendMessage(final String message) throws NamingException, JMSException {
		try {
			this.createConnection();
			objectMessage = session.createObjectMessage(message);
			sender.send(objectMessage);
			session.commit();
			LOGGER.info("Single message");
		} catch (JMSException e) {
			LOGGER.info("batch messages rollback");
			session.rollback();
			e.printStackTrace();
		}
	}

	public void sendMessages(final List<String> messages) throws NamingException, JMSException {
		try {
			objectMessage = session.createObjectMessage((Serializable) messages);
			sender.send(objectMessage);
			session.commit();
			LOGGER.info("batch messages sent");
		} catch (JMSException e) {
			LOGGER.info("batch messages rollback");
			session.rollback();
			e.printStackTrace();
		}
	}

	public void createConnection() throws NamingException {
		try {
			ctx = new InitialContext();
			queue = (Queue) ctx.lookup("java:/jms/queue/TestQ");
			factory = (QueueConnectionFactory) ctx.lookup("java:/JmsXA");
			connection = factory.createConnection();
			session = connection.createSession(true, Session.AUTO_ACKNOWLEDGE);
			sender = session.createProducer(queue);

		} catch (JMSException e) {
			e.printStackTrace();
		}

	}
}